# flipnote.py
A Python library for processing Flipnote Studio (3D) files.

Currently `kwz` and `ppm` are [kwz-parser](https://github.com/Flipnote-Collective/kwz-parser) and [ppm-parser](https://github.com/Flipnote-Collective/ppm-parser) respectively, and are created by the Flipnote Collective.

# Building

```shell
./build.sh
```
